==> haskell-skylighting-format-latex-0.1-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-6GyGOexqqTT2OvEJhvcUmY
key:                  skylighting-format-latex-0.1-6GyGOexqqTT2OvEJhvcUmY
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  ef9bf41d67f42d4c11c8f8cc5fc9d45d
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-6GyGOexqqTT2OvEJhvcUmY
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.1.1-DRMvtHMoGN57xvbd3y7Mea text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-latex-0.1-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-DHPQ8XpqXo21if3aIuVgFp
key:                  skylighting-format-latex-0.1-DHPQ8XpqXo21if3aIuVgFp
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  522602920ee6a405587b748b1fcf1d81
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-DHPQ8XpqXo21if3aIuVgFp
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.1.1-597e0KBX1jE5mRW1kbd7AP text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
